#include "EmonLib.h"                   // Include Emon Library
EnergyMonitor emon1;                   // Create an instance

  /*
   * Continually test current draw
   * No violations: Sleep for 1 second and test again
   * If violation is found: increase counter
   * 1st violation: sleep 30 seconds
   * 2nd violation: SMS then sleep 10 minutes
   * 3rd violation: sleep 1 hour
   * 4th violation: reset to 3rd violation (and sleep 1 hour)
   * If violation clears, send SMS
   */

/* **************LookUp Table Current Draw*************/
float LightSensorA = .10;  /* Trigger Value */
float LightSensorB = .70;  /* Trigger Value */
float LightSensorC = .60;  /* Trigger Value */

/***************LookUp Table RelayDelay*********/
unsigned long RelayDelay[] = {1000, 30000, 600000, 3600000};  /*  1 sec, 30 sec, 10 min, 1 hour */
unsigned long RelayDelayQuiet = 10000;                        /* 10 seconds to wait for "quiet" */
unsigned int max_violations = 3;

/*****************Relay *******************/
unsigned long relay = 4;

unsigned int violations = 0;
boolean inviolation = false;
 
void setup()
{  
  Serial.begin(9600);
  pinMode(relay, OUTPUT);                 // make Relay Pin an outpin
  emon1.current(1, 111.1);                // Current: input pin, calibration
}

void loop()
{

  Serial.println("Turn lights on");       // for debugging 
  digitalWrite(relay, LOW);               // Switch Off relay (turn On Lights)
  delay( RelayDelayQuiet );               // Wait for current draw to stabilize

  double Irms = emon1.calcIrms(1480);     // Read pin and calculate Irms only   
  Serial.println("Irms: " + Irms + " ");  // Print Irms for debugging purposes
 
  if(Irms < LightSensorA)                 // Check against "no load" threshold
  {                                       // All is good, current is below threshold
    violations = 0;                       // Reset violations count and keep on going
    if( inviolation == true )
    {
      inviolation = false;
      // Send an SMS message here!!!  The violation has cleared - nobody is stealing electricity
    }
  }
  else  if (Irms < LightSensorB)          // Check against "current draw" threshold
  {                                       // Some current is being drawn - but not enough to worry about
    // Do nothing???
  }
  
  else  if (Irms > LightSensorB)          // Check against "current draw" threshold
  {                                       // Too much current is being drawn
    Serial.println("Turn lights off");    // for debugging

    digitalWrite(relay, HIGH);            // switch ON relay (turns off lights)
    violations = violations + 1;          // Increase violations and increase delay
    inviolation = true;                   // Note we are in the middle of a violation
  }
 
  if( violations == 2 )
  {
    // Send an SMS message here!!!  Someone is trying to steal electricity
  } 
  else if( violations > max_violations )  // Look for repeat offenses
  {
    violations = max_violations;          // Limit on RelayDelay array    
  }
  
  Serial.println("Delay for " + RelayDelay[violations] );
  delay( RelayDelay[violations] );        // Sleep at least 1 second
  
}
